@@ -18,30 +18,25 @@ If not, see <https://www.gnu.org/licenses/>.
 */
 
 
-function mathJaxUpdate(){
-  jsLogger('[MathJax] - Page formatting')
+// Must be defined to fulfill the legacy subscription logistic:
+function mathJaxUpdate(){}
 
-  window.MathJax.startup.output.clearCache()
-  window.MathJax.typesetClear()
-  window.MathJax.texReset()
-  window.MathJax.typesetPromise()
-}
-const mathJaxIsReady = subscribeWhenReady('mathJax', mathJaxUpdate)
+subscribeWhenReady('MathJax')
 
 
 window.MathJax = {
   startup: {
     ready: () => {
-      jsLogger("[MathJax] - Setting up");
+      LOGGER_CONFIG.ACTIVATE && console.log("[MathJax] - Setting up");
       MathJax.startup.defaultReady();
-      jsLogger("[MathJax] - Ready");
-      mathJaxIsReady()
-      mathJaxUpdate()
+      LOGGER_CONFIG.ACTIVATE && console.log("[MathJax] - Ready");
     },
   },
-  loader: {load: ['[tex]/cancel']},
+  loader: {
+    load: ['[tex]/cancel', 'output/svg', '[tex]/color']
+  },
   tex: {
-    packages: {'[+]': ['cancel']},
+    packages: {'[+]': ['cancel', 'color']},
     inlineMath: [["\\(", "\\)"]],
     displayMath: [["\\[", "\\]"]],
     processEscapes: true,
@@ -51,4 +46,4 @@ window.MathJax = {
     ignoreHtmlClass: ".*|",
     processHtmlClass: "arithmatex",
   },
-};
+}
